# Phase 1: Modern Agent Frameworks (2025)

This directory contains examples demonstrating the Arc Tracing SDK's integration with the latest 2025 agent frameworks. These examples show comprehensive tracing for modern multi-agent orchestration systems.

## 🎯 Framework Coverage

### 1. OpenAI Agents SDK (`openai_agents_example.py`)
- **Replaces**: OpenAI Swarm (deprecated)
- **Features**: Production-ready multi-agent orchestration
- **Tracing**: Agent execution, handoffs, tool usage, token metrics

### 2. LangGraph (`langgraph_example.py`) 
- **Replaces**: LangChain Agents (legacy)
- **Features**: State graphs, conditional logic, complex workflows
- **Tracing**: Node execution, state transitions, edge decisions

### 3. LlamaIndex AgentWorkflow (`llamaindex_agentworkflow_example.py`)
- **Evolution**: From RAG framework to multi-agent platform
- **Features**: FunctionAgent, ReActAgent, workflow orchestration
- **Tracing**: Agent coordination, tool calls, workflow states

## 🚀 Running the Examples

### Prerequisites
```bash
pip install arc-tracing opentelemetry-api opentelemetry-sdk
```

### Execute Examples
```bash
# OpenAI Agents SDK example
python examples/phase1_modern_agents/openai_agents_example.py

# LangGraph example  
python examples/phase1_modern_agents/langgraph_example.py

# LlamaIndex AgentWorkflow example
python examples/phase1_modern_agents/llamaindex_agentworkflow_example.py
```

## 📊 Trace Data Captured

Each example captures comprehensive tracing data optimized for closed-loop RL:

### Agent-Level Traces
- Agent names, types, and configurations
- Input/output pairs for RL training
- Execution duration and performance metrics
- Tool usage patterns

### Framework-Level Traces  
- State transitions (LangGraph)
- Workflow orchestration (LlamaIndex)
- Agent handoffs (OpenAI Agents SDK)
- Conditional logic paths

### System-Level Traces
- Token usage and costs
- Error rates and patterns
- Performance bottlenecks
- Framework detection results

## 🔄 Integration with RL Pipeline

The traces generated by these examples feed directly into the Arc platform's closed-loop RL system:

1. **Trace Collection**: Automatic instrumentation captures execution data
2. **Signal Extraction**: Custom signals for relevance, accuracy, performance
3. **Reward Function**: Generated based on trace patterns and outcomes
4. **Model Training**: RL optimization using traced agent behaviors
5. **Deployment**: Optimized agents deployed back to production

## 📝 Mock Components

These examples use mock components to simulate the actual frameworks. In production:

- Replace mock classes with actual framework imports
- The Arc Tracing SDK will automatically detect and instrument real frameworks
- All tracing functionality remains identical

## 🔧 Customization

Each example can be customized for your specific use case:

- **Agent Configuration**: Modify agent names, instructions, tools
- **Workflow Logic**: Adjust state transitions, conditional paths
- **Trace Attributes**: Add custom signals for RL optimization
- **Error Handling**: Implement production-ready error recovery

## 📈 Next Steps

After running these examples:

1. **View Traces**: Check your Arc platform dashboard or local trace files
2. **Analyze Patterns**: Review agent performance and decision patterns  
3. **Configure RL**: Set up reward functions based on your objectives
4. **Deploy Optimized**: Use RL-trained agents in production

For more advanced examples and production deployment guidance, see the full documentation at `docs/`.